#
# spec file for package perl-Test-Spec
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Test-Spec
Name:           perl-Test-Spec
Version:        0.540.0
Release:        1.1
# 0.54 -> normalize -> 0.540.0
%define cpan_version 0.54
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Write tests in a declarative specification style
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/A/AK/AKZHAN/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Devel::GlobalPhase)
BuildRequires:  perl(Package::Stash) >= 0.230
BuildRequires:  perl(TAP::Parser)
BuildRequires:  perl(Test::Deep) >= 0.103
BuildRequires:  perl(Test::More) >= 0.88
BuildRequires:  perl(Test::Trap)
BuildRequires:  perl(Tie::IxHash)
Requires:       perl(Devel::GlobalPhase)
Requires:       perl(Package::Stash) >= 0.230
Requires:       perl(TAP::Parser)
Requires:       perl(Test::Deep) >= 0.103
Requires:       perl(Test::More) >= 0.88
Requires:       perl(Test::Trap)
Requires:       perl(Tie::IxHash)
Provides:       perl(Test::Spec) = %{version}
Provides:       perl(Test::Spec::Context)
Provides:       perl(Test::Spec::Example)
Provides:       perl(Test::Spec::ExportProxy)
Provides:       perl(Test::Spec::Mocks)
Provides:       perl(Test::Spec::Mocks::Expectation)
Provides:       perl(Test::Spec::Mocks::MockObject)
Provides:       perl(Test::Spec::Mocks::Stub)
Provides:       perl(Test::Spec::SharedHash)
Provides:       perl(Test::Spec::TodoExample)
%undefine       __perllib_provides
%{perl_requires}

%description
This is a declarative specification-style testing system for
behavior-driven development (BDD) in Perl. The tests (a.k.a. examples) are
named with strings instead of subroutine names, so your fingers will suffer
less fatigue from underscore-itis, with the side benefit that the test
reports are more legible.

This module is inspired by and borrows heavily from at
http://rspec.info/documentation, a BDD tool for the Ruby programming
language.

%prep
%autosetup -n %{cpan_name}-%{cpan_version} -p1

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README.md

%changelog
* Thu Jun 12 2025 Tina Müller <tina.mueller@suse.com>
- Normalize CPAN version
  See https://github.com/openSUSE/cpanspec/issues/47 for details
* Mon Mar  5 2018 coolo@suse.com
- updated to 0.54
  see /usr/share/doc/packages/perl-Test-Spec/Changes
  0.54 Tue Nov 21 12:46:00 MSK 2017
  - `around` method added to allow localized variables and other local setup.
    Call `yield` method to run examples by `around` CODE.
    Contributed by @akzhan
  - Replace some `use base` with `use parent` and other minor updates.
    Contributed by @akzhan
  - Now tested under Perl 5.22-5.26 too
    Contributed by @akzhan
  - predictable_destroy spec fixed under Perl 5.8
    Contributed by @akzhan
* Mon Sep  4 2017 coolo@suse.com
- updated to 0.53
  see /usr/share/doc/packages/perl-Test-Spec/Changes
  0.53 Wed Aug 16 09:49:00 BST 2017
  - POD links are clickable
    Contributed by @manwar (issue #42)
* Wed Aug 16 2017 coolo@suse.com
- updated to 0.52
  see /usr/share/doc/packages/perl-Test-Spec/Changes
  0.52 Tue Aug 15 10:20:00 BST 2017
  - Pass example instance to each test
    Contributed by @jamhed (issue #30, #41)
  - Fix runtests to run all examples that match any of the patterns
    Contributed by @mpw96 (issue #37, #38)
  - Ensure META.json includes requirements
    Reported by @joelrebel (issue #39)
* Sat Aug  1 2015 coolo@suse.com
- updated to 0.51
  see /usr/share/doc/packages/perl-Test-Spec/Changes
  0.51 Mon Jul 27 20:05:00 BST 2015
  - Fixed top level describe blocks running out of order
    Contributed by @mla (issue #28)
* Mon Apr 20 2015 coolo@suse.com
- updated to 0.50
  see /usr/share/doc/packages/perl-Test-Spec/Changes
  0.50 Sun Apr 19 18:13:00 BST 2015
  - Removed several memory leaks
    Reported by @JRaspass (issue #24)
  - any_number() no longer fails if it is never called
    Contributed by @ptolemarch and @cavemanpi (issue #25)
* Tue Apr 14 2015 coolo@suse.com
- updated to 0.49
  see /usr/share/doc/packages/perl-Test-Spec/Changes
  0.49 Sun Jan 18 12:56:00 EST 2015
  - Added with_deep
    Contributed by Andy Jones (issue #21)
  - Documented memory leak in stub()
    Reported by Victor Efimov (issue #14)
  - Added Travis CI info
    Contributed by Andy Jones (issue #23)
  - Fixed mock() example documentation
    Reported by Victor Efimov (issue #15)
    Contributed by Andy Jones (issue #22)
  0.48 Tue Jan 06 22:52:00 EST 2015
  - Testing fixes for Alpha branch of Test::More
    Contributed by Chad Granum (issue #18)
  - Metadata fixes
    Contributed by Graham Knop (issue #19)
* Tue Nov 26 2013 coolo@suse.com
- updated to 0.47
  - added repository metadata for CPAN
    Contributed by David Steinbrunner (issue #1)
* Tue Jun  4 2013 coolo@suse.com
- updated to 0.46
  - with() enables argument matching on mocked methods
  - raises() makes mocked methods raise exceptions
    Contributed by Kjell-Magne Øierud (issue #12)
  - Add support for TAP version 13.
    Contributed by Michael G. Schwern (issue #11)
  - Allow shared_examples_for to be defined in any context.
  - Fixed runtests() to honor its contract to run only the examples specified
    in its @patterns parameter or SPEC environment variable.
* Fri Mar  9 2012 coolo@suse.com
- updated to 0.42
  - Added context() and xcontext() aliases for describe/xdescribe
    (reported by intrigeri)
  - Added license info to Makefile.PL (RT#75400)
  - Fixed test suite problems on Windows
* Thu Feb 16 2012 coolo@suse.com
- updated to 0.40
  - Fixed problem that caused Test::Spec usage errors (e.g. 'describe "foo";'
    without a subroutine argument) to be reported from inside the library,
    instead of the caller's perspective where the actual error is.
* Thu Dec 22 2011 coolo@suse.com
- update to 0.39
  - Added xit/xthey/xdescribe to mark TODO tests, inspired by the
    Jasmine JavaScript framework.
    Contributed by Marian Schubert (issue #10).
  - Added share() function to facilitate spec refactoring.
  - Fixed bug where shared examples defined in one package could not be
    used in another package.
  - Improved reporting of errors using spec_helper.
  - Minor documentation formatting fixes
  - Fixed test suite for Windows environments.
  - Added spec_helper utility function to load helper scripts
    relative to the spec.
* Tue Jun 14 2011 pascal.bleser@opensuse.org
- update to 0.33:
  * added shared_examples_for/it_should_behave_like to allow factorization of
    tests
* Sat Jun 11 2011 pascal.bleser@opensuse.org
- update to 0.32:
  * fixed a problem with the tests that occurred only when Package::Stash::XS
    was not installed (issue #8)
* Wed Jun  8 2011 pascal.bleser@opensuse.org
- initial version (0.31)
